:root {
	--jp-carousel-primary-color: #fff;
	--jp-carousel-primary-subtle-color: #999;
	--jp-carousel-bg-color: #000;
	--jp-carousel-bg-faded-color: #222;
	--jp-carousel-border-color: #3a3a3a;
}

:root .jp-carousel-light {
	--jp-carousel-primary-color: #000;
	--jp-carousel-primary-subtle-color: #646970;
	--jp-carousel-bg-color: #fff;
	--jp-carousel-bg-faded-color: #fbfbfb;
	--jp-carousel-border-color: #dcdcde;
}

.jp-carousel-overlay .swiper-button-prev,
.jp-carousel-overlay .swiper-container-rtl .swiper-button-next,
.jp-carousel-overlay .swiper-button-next,
.jp-carousel-overlay .swiper-container-rtl .swiper-button-prev {
	background-image: none;
}
/* end of temporary fix */

[data-carousel-extra]:not( .jp-carousel-wrap ) img, [data-carousel-extra]:not( .jp-carousel-wrap ) img + figcaption {
	cursor: pointer;
}

.jp-carousel-wrap * {
	line-height: inherit;
}

.jp-carousel-wrap.swiper-container {
	height: auto;
	width: 100vw;
}

.jp-carousel-overlay .swiper-zoom-container {
	background-size: 200%;
	background-repeat: no-repeat;
	background-position: center;
}

/*
To prevent flash of prev/next image scale transition after pinch zoom we need to hide them.
Swiper does not add a class of `swiper-slide-zoomed` to slides on pinch and zoom
so we have to target all affected elements in touch devices.
*/
.jp-carousel-overlay .swiper-slide.swiper-slide-prev .swiper-zoom-container img,
.jp-carousel-overlay .swiper-slide.swiper-slide-next .swiper-zoom-container img {
	transition: none !important;
}

.jp-carousel-overlay .swiper-button-prev,
.jp-carousel-overlay .swiper-button-next {
	opacity: 0.5;
	transition: 0.5s opacity ease-out;
	height: initial;
	width: initial;
	padding: 20px 40px;
	background-image: none;
}

.jp-carousel-overlay .swiper-button-prev:hover,
.jp-carousel-overlay .swiper-button-next:hover {
	opacity: 1;
}

.jp-carousel-overlay .swiper-button-next:after,
.jp-carousel-overlay .swiper-container-rtl .swiper-button-next:after,
.jp-carousel-overlay .swiper-button-prev:after,
.jp-carousel-overlay .swiper-container-rtl .swiper-button-prev:after {
	content: none;
}

.jp-carousel-overlay .swiper-button-prev svg,
.jp-carousel-overlay .swiper-button-next svg {
	height: 30px;
	width: 28px;
	background: var(--jp-carousel-bg-color);
	border-radius: 4px;
}

.jp-carousel-overlay .swiper-button-prev svg:hover,
.jp-carousel-overlay .swiper-button-next svg:hover {
	background: var(--jp-carousel-primary-subtle-color);
}

.jp-carousel-overlay {
	font-family: 'Helvetica Neue', sans-serif !important;
	z-index: 2147483647;
	overflow-x: hidden;
	overflow-y: auto;
	direction: ltr;
	position: fixed;
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
	background: var(--jp-carousel-bg-color);
}

.jp-carousel-overlay * {
	box-sizing: border-box;
}

/* Fix for Twenty Nineteen theme compatibility */
.jp-carousel-overlay h1:before,
.jp-carousel-overlay h2:before,
.jp-carousel-overlay h3:before {
	content: none;
	display: none;
}

.jp-carousel-overlay .swiper-container .swiper-button-prev {
	left: 0;
	right: auto;
}

.jp-carousel-overlay .swiper-container .swiper-button-next {
	right: 0;
	left: auto;
}

.jp-carousel-overlay .swiper-container.swiper-container-rtl .swiper-button-prev,
.jp-carousel-overlay .swiper-container.swiper-container-rtl .swiper-button-next {
	transform: scaleX( -1 );
}

.jp-carousel-container {
	display: grid;
	grid-template-rows: 1fr 64px; /* 1. main carousel, 2. info area as footer */
	height: 100%;
}

.jp-carousel-hide-controls .jp-carousel-container {
	grid-template-rows: 1fr;
}

.jp-carousel-hide-controls .swiper-wrapper {
	margin-top: -32px; /* Compensate for the remove of the height of the info bar. */
}


.jp-carousel-hide-controls .jp-swiper-button-next,
.jp-carousel-hide-controls .jp-swiper-button-prev {
	margin-top: -54px; /* The height of the info bar plus any top padding on the nav button itself. */
}

.jp-carousel-msg {
	font-family: 'Open Sans', sans-serif;
	font-style: normal;
	display: inline-block;
	line-height: 19px;
	padding: 11px 15px;
	font-size: 14px;
	text-align: center;
	margin: 25px 20px 0 2px;
	background-color: var(--jp-carousel-primary-color);
	border-left: 4px solid #ffba00;
	-webkit-box-shadow: 0 1px 1px 0 rgba( 0, 0, 0, 0.1 );
	box-shadow: 0 1px 1px 0 rgba( 0, 0, 0, 0.1 );
}

.jp-carousel-info {
	display: flex;
	flex-direction: column;
	text-align: left !important;
	-webkit-font-smoothing: subpixel-antialiased !important;
	z-index: 100;
	background-color: var(--jp-carousel-bg-color);
	transition: opacity 200ms ease-out;
	opacity: 1;
}

.jp-carousel-hide-controls .jp-carousel-info {
	visibility: hidden;
	height: 0;
	overflow: hidden;
}

.jp-carousel-info-footer {
	position: relative;
	background-color: var(--jp-carousel-bg-color);
	height: 64px;
	display: flex;
	align-items: center;
	justify-content: space-between;
	width: 100vw;
}

.jp-carousel-info-extra {
	display: none;
	background-color: var(--jp-carousel-bg-color);
	padding: 35px;
	width: 100vw;
	border-top: 1px solid var(--jp-carousel-bg-faded-color);
}

.jp-carousel-title-and-caption {
	margin-bottom: 15px;
}

.jp-carousel-info-extra.jp-carousel-show {
	display: block;
}

.jp-carousel-info ::selection {
	background: var(--jp-carousel-primary-color); /* Safari */
	color: var(--jp-carousel-primary-color);
}

.jp-carousel-info ::-moz-selection {
	background: var(--jp-carousel-primary-color); /* Firefox */
	color: var(--jp-carousel-primary-color);
}

.jp-carousel-photo-info {
	left: 0 !important;
	width: 100% !important;
}

.jp-carousel-comments-wrapper {
	padding: 0;
	width: 100% !important;
	display: none;
}

.jp-carousel-comments-wrapper.jp-carousel-show {
	display: block;
}

.jp-carousel-comments-wrapper > .jp-carousel-photo-info {
	display: none;
}

.jp-carousel-transitions .jp-carousel-photo-info {
	-webkit-transition: 400ms ease-out;
	-moz-transition: 400ms ease-out;
	-o-transition: 400ms ease-out;
	transition: 400ms ease-out;
}

.jp-carousel-buttons {
	margin: -18px -20px 15px;
	padding: 8px 10px;
	border-bottom: 1px solid #222;
	background: #222;
	text-align: center;
}

div.jp-carousel-buttons a {
	border: none !important;
	color: var(--jp-carousel-primary-subtle-color);
	font: normal 11px/1.2em 'Helvetica Neue', sans-serif !important;
	letter-spacing: 0 !important;
	padding: 5px 2px 5px 0;
	text-decoration: none !important;
	text-shadow: none !important;
	vertical-align: middle;
	-webkit-font-smoothing: subpixel-antialiased;
}

div.jp-carousel-buttons a:hover {
	color: var(--jp-carousel-primary-color);
	border: none !important;
}

.jp-carousel-transitions div.jp-carousel-buttons a:hover {
	-webkit-transition: none !important;
	-moz-transition: none !important;
	-o-transition: none !important;
	transition: none !important;
}

.jp-carousel-slide,
.jp-carousel-slide img {
	-webkit-transform: translate3d( 0, 0, 0 );
	-moz-transform: translate3d( 0, 0, 0 );
	-o-transform: translate3d( 0, 0, 0 );
	-ms-transform: translate3d( 0, 0, 0 );
	transform: translate3d( 0, 0, 0 );
}

.jp-carousel-close-hint {
	cursor: default;
	letter-spacing: 0 !important;
	position: fixed;
	top: 20px;
	right: 30px;
	padding: 10px;
	text-align: right;
	width: 45px;
	height: 45px;
	z-index: 15;
	color: var(--jp-carousel-primary-color);
	cursor: pointer;
	transition: opacity 200ms ease-out;
}

.jp-carousel-transitions .jp-carousel-close-hint {
	-webkit-transition: color 200ms linear;
	-moz-transition: color 200ms linear;
	-o-transition: color 200ms linear;
	transition: color 200ms linear;
}

.jp-carousel-close-hint svg {
	padding: 3px 2px;
	background: var(--jp-carousel-bg-color);
	border-radius: 4px;
}

.jp-carousel-close-hint svg:hover {
	background: var(--jp-carousel-primary-subtle-color);
}

.jp-carousel-close-hint:hover {
	color: var(--jp-carousel-primary-color);
}

.jp-carousel-close-hint:hover span {
	border-color: var(--jp-carousel-primary-color);
}

/** Pagination Start **/
.jp-carousel-pagination-container {
	flex: 1;
	margin: 0 15px 0 35px;
}

.jp-swiper-pagination,
.jp-carousel-pagination {
	color: var(--jp-carousel-primary-color);
	font-size: 15px; /* same as .jp-carousel-info-footer .jp-carousel-photo-title  */
	font-weight: normal;
	white-space: nowrap;
	display: none;
	position: static !important;
}

.jp-carousel-pagination-container .swiper-pagination {
	text-align: left;
	line-height: 8px;
}

.jp-carousel-pagination {
	padding-left: 5px;
}

.jp-swiper-pagination .swiper-pagination-bullet {
	background: var(--jp-carousel-primary-subtle-color);
	margin: 0 4px;
}

.jp-swiper-pagination .swiper-pagination-bullet.swiper-pagination-bullet-active {
	background: var(--jp-carousel-primary-color);
}

.jp-swiper-pagination .swiper-pagination-bullet:not( .swiper-pagination-bullet-active ) {
	background: var(--jp-carousel-primary-color);
	opacity: 0.5;
}
/** Pagination End **/

/** Title and Desc Start **/
.jp-carousel-info-footer .jp-carousel-photo-title-container {
	flex-basis: 50vw;
	flex: 4;
	justify-content: center;
	overflow: hidden;
	margin: 0;
}

.jp-carousel-photo-title,
.jp-carousel-photo-caption {
	background: none !important;
	border: none !important;
	display: inline-block;
	font: normal 20px/1.3em 'Helvetica Neue', sans-serif;
	line-height: normal;
	letter-spacing: 0 !important;
	margin: 0 0 10px 0;
	padding: 0;
	overflow: hidden;
	text-shadow: none !important;
	text-transform: none !important;
	color: var(--jp-carousel-primary-color);
}

.jp-carousel-info-footer .jp-carousel-photo-caption {
	text-align: center;
	font-size: 15px; /* same as .jp-carousel-pagination */
	white-space: nowrap;
	color: var(--jp-carousel-primary-subtle-color);
	cursor: pointer;
	margin: 0;
	text-overflow: ellipsis;
}

.jp-carousel-info-footer .jp-carousel-photo-caption p {
	margin: 0;
}

.jp-carousel-photo-title {
	font-size: 32px;
	margin-bottom: 2px;
}

.jp-carousel-photo-description {
	color: var(--jp-carousel-primary-subtle-color);
	font-size: 16px;
	margin: 25px 0;
	width: 100%;
}

.jp-carousel-photo-description {
	overflow: hidden;
	overflow-wrap: break-word;
}

.jp-carousel-photo-description p {
	color: var(--jp-carousel-primary-subtle-color);
	line-height: 1.4;
	margin-bottom: 0;
}

.jp-carousel-photo-description p a,
.jp-carousel-comments p a,
.jp-carousel-info h2 a {
	color: var(--jp-carousel-primary-color) !important;
	border: none !important;
	text-decoration: underline !important;
	font-weight: normal !important;
	font-style: normal !important;
}

.jp-carousel-photo-description p strong,
.jp-carousel-photo-description p b {
	font-weight: bold;
	color: var(--jp-carousel-primary-subtle-color);
}

.jp-carousel-photo-description p em,
.jp-carousel-photo-description p i {
	font-style: italic;
	color: var(--jp-carousel-primary-subtle-color);
}

.jp-carousel-photo-description p a:hover,
.jp-carousel-comments p a:hover,
.jp-carousel-info h2 a:hover {
	color: var(--jp-carousel-primary-subtle-color) !important;
}

.jp-carousel-photo-description p:empty {
	display: none;
}

.jp-carousel-photo-info h1:before,
.jp-carousel-photo-info h1:after,
.jp-carousel-comments-wrapper h1:before,
.jp-carousel-comments-wrapper h1:after {
	content: none !important;
}

.jp-carousel-caption {
	font-size: 14px;
	font-weight: normal;
	margin: 0;
}

/** Title and Desc End **/

/** Meta Box Start **/
.jp-carousel-image-meta {
	color: var(--jp-carousel-primary-color);
	font-size: 13px;
	font: 12px/1.4 'Helvetica Neue', sans-serif !important;
	width: 100%;
	display: none;
}

.jp-carousel-image-meta.jp-carousel-show {
	display: block;
}

.jp-carousel-image-meta li,
.jp-carousel-image-meta h5 {
	font-family: 'Helvetica Neue', sans-serif !important;
	position: inherit !important;
	top: auto !important;
	right: auto !important;
	left: auto !important;
	bottom: auto !important;
	background: none !important;
	border: none !important;
	font-weight: 400 !important;
	line-height: 1.3em !important;
}

.jp-carousel-image-meta ul {
	margin: 0 !important;
	padding: 0 !important;
	list-style: none !important;
}

.jp-carousel-image-meta li {
	width: 48% !important;
	display: inline-block !important;
	vertical-align: top !important;
	margin: 0 2% 15px 0 !important;
	color: var(--jp-carousel-primary-color) !important;
	font-size: 13px !important;
}

.jp-carousel-image-meta h5 {
	color: var(--jp-carousel-primary-subtle-color) !important;
	text-transform: uppercase !important;
	font-size: 10px !important;
	margin: 0 0 2px !important;
	letter-spacing: 0.1em !important;
}

a.jp-carousel-image-download {
	display: inline-block;
	clear: both;
	color: var(--jp-carousel-primary-subtle-color);
	line-height: 1;
	font-weight: 400;
	font-size: 14px;
	text-decoration: none;
}

a.jp-carousel-image-download svg {
	display: inline-block;
	vertical-align: middle;
	margin: 0 3px;
	padding-bottom: 2px;
}

a.jp-carousel-image-download span.photo-size {
	font-size: 11px;
	border-radius: 1em;
	margin-left: 2px;
	display: inline-block;
}

a.jp-carousel-image-download span.photo-size-times {
	padding: 0 1px 0 2px;
}

/** Meta Box End **/

/** Comments Start **/
.jp-carousel-comments {
	font: 15px/1.7 'Helvetica Neue', sans-serif !important;
	font-weight: 400;
	background: none transparent;
	width: 100%;
	bottom: 10px;
	margin-top: 20px;
}

.jp-carousel-comments p a:hover,
.jp-carousel-comments p a:focus,
.jp-carousel-comments p a:active {
	color: var(--jp-carousel-primary-color) !important;
}

.jp-carousel-comment {
	background: none transparent;
	color: var(--jp-carousel-primary-subtle-color);
	overflow: auto;
	width: 100%;
	display: flex;
}

.jp-carousel-comment + .jp-carousel-comment {
	margin-top: 20px;
}

.jp-carousel-comment:last-of-type {
	margin-bottom: 20px;
}

.jp-carousel-comment p {
	color: var(--jp-carousel-primary-subtle-color) !important;
}

.jp-carousel-comment .comment-author {
	font-size: 15px;
	font-weight: 500;
	padding: 0;
	width: auto;
	display: inline;
	float: none;
	border: none;
	margin: 0;
}

.jp-carousel-comment .comment-author a {
	color: var(--jp-carousel-primary-color);
}

.jp-carousel-comment .comment-gravatar {
	float: none;
	margin-right: 10px;
}

.jp-carousel-comment .comment-content {
	border: none;
	padding: 0;
}

.jp-carousel-comment .avatar {
	margin: 0;
	-moz-border-radius: 4px;
	-webkit-border-radius: 4px;
	border-radius: 4px;
	border: none !important;
	padding: 0 !important;
	background-color: transparent !important;
	min-width: 64px;
	min-height: 64px;
	width: 64px;
	height: 64px;
}

.jp-carousel-comment .comment-date {
	color: var(--jp-carousel-primary-subtle-color);
	font-size: 11px;
	border-bottom: 1px solid var(--jp-carousel-bg-faded-color);
	margin-bottom: 6px;
}

#jp-carousel-comment-form {
	margin: 0 0 10px !important;
	width: 100%;
}

#jp-carousel-comment-form.jp-carousel-is-disabled {
	opacity: 0.5;
	pointer-events: none;
}

textarea#jp-carousel-comment-form-comment-field {
	background: var(--jp-carousel-bg-faded-color);
	border: 1px solid var(--jp-carousel-border-color);
	color: var(--jp-carousel-primary-subtle-color);
	font: 16px/1.4 'Helvetica Neue', sans-serif !important;
	width: 100%;
	padding: 10px 10px 5px;
	margin: 0;
	float: none;
	height: 147px;
	-webkit-box-shadow: inset 2px 2px 2px rgba( 0, 0, 0, 0.1 );
	box-shadow: inset 2px 2px 2px rgba( 0, 0, 0, 0.1 );
	-moz-border-radius: 3px;
	-webkit-border-radius: 3px;
	border-radius: 3px;
	overflow: hidden;
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	box-sizing: border-box;
}

textarea#jp-carousel-comment-form-comment-field::-webkit-input-placeholder {
	color: #555;
}

textarea#jp-carousel-comment-form-comment-field:focus {
	background: var(--jp-carousel-bg-faded-color);
	color: var(--jp-carousel-primary-subtle-color);
}

textarea#jp-carousel-comment-form-comment-field:focus::-webkit-input-placeholder {
	color: var(--jp-carousel-primary-subtle-color);
}

#jp-carousel-loading-overlay {
	display: none;
	position: fixed;
	top: 0;
	bottom: 0;
	left: 0;
	right: 0;
}

#jp-carousel-loading-wrapper {
	display: flex;
	align-items: center;
	justify-content: center;
	height: 100vh;
	width: 100vw;
}

#jp-carousel-library-loading,
#jp-carousel-library-loading:after {
	border-radius: 50%;
	width: 40px;
	height: 40px;
}

#jp-carousel-library-loading {
	float: left;
	margin: 22px 0 0 10px;
	font-size: 10px;
	position: relative;
	text-indent: -9999em;
	border-top: 8px solid rgba( 255, 255, 255, 0.2 );
	border-right: 8px solid rgba( 255, 255, 255, 0.2 );
	border-bottom: 8px solid rgba( 255, 255, 255, 0.2 );
	border-left: 8px solid var(--jp-carousel-primary-color);
	-webkit-transform: translateZ( 0 );
	-ms-transform: translateZ( 0 );
	transform: translateZ( 0 );
	-webkit-animation: load8 1.1s infinite linear;
	animation: load8 1.1s infinite linear;
}

#jp-carousel-comment-form-spinner,
#jp-carousel-comment-form-spinner:after {
	border-radius: 50%;
	width: 20px;
	height: 20px;
}
#jp-carousel-comment-form-spinner {
	display: none;
	float: left;
	margin: 22px 0 0 10px;
	font-size: 10px;
	position: absolute; /* relative to .jp-carousel-comment-form-container */
	text-indent: -9999em;
	border-top: 4px solid rgba( 255, 255, 255, 0.2 );
	border-right: 4px solid rgba( 255, 255, 255, 0.2 );
	border-bottom: 4px solid rgba( 255, 255, 255, 0.2 );
	border-left: 4px solid var(--jp-carousel-primary-color);
	-webkit-transform: translateZ( 0 );
	-ms-transform: translateZ( 0 );
	transform: translateZ( 0 );
	-webkit-animation: load8 1.1s infinite linear;
	animation: load8 1.1s infinite linear;
	margin: 0 auto;
	top: calc( 50% - 15px );
	left: 0;
	bottom: 0;
	right: 0;
}

@-webkit-keyframes load8 {
	0% {
		-webkit-transform: rotate( 0deg );
		transform: rotate( 0deg );
	}
	100% {
		-webkit-transform: rotate( 360deg );
		transform: rotate( 360deg );
	}
}
@keyframes load8 {
	0% {
		-webkit-transform: rotate( 0deg );
		transform: rotate( 0deg );
	}
	100% {
		-webkit-transform: rotate( 360deg );
		transform: rotate( 360deg );
	}
}

.jp-carousel-info-content-wrapper {
	max-width: 800px;
	margin: auto;
}

#jp-carousel-comment-form-submit-and-info-wrapper {
	display: none;
	overflow: hidden;
	width: 100%;
}

#jp-carousel-comment-form-commenting-as input {
	background: var(--jp-carousel-bg-color);
	border: 1px solid var(--jp-carousel-border-color);
	color: var(--jp-carousel-primary-subtle-color);
	font: 16px/1.4 'Helvetica Neue', sans-serif !important;
	padding: 10px;
	float: left;
	-webkit-box-shadow: inset 2px 2px 2px rgba( 0, 0, 0, 0.2 );
	box-shadow: inset 2px 2px 2px rgba( 0, 0, 0, 0.2 );
	-moz-border-radius: 2px;
	-webkit-border-radius: 2px;
	border-radius: 2px;
	width: 285px;
}

#jp-carousel-comment-form-commenting-as input:focus {
	background: var(--jp-carousel-bg-faded-color);
	color: var(--jp-carousel-primary-subtle-color);
}

#jp-carousel-comment-form-commenting-as p {
	font: 400 13px/1.7 'Helvetica Neue', sans-serif !important;
	margin: 22px 0 0;
	float: left;
}

#jp-carousel-comment-form-commenting-as fieldset {
	float: left;
	border: none;
	margin: 20px 0 0 0;
	padding: 0;
	clear: both;
}

#jp-carousel-comment-form-commenting-as label {
	font: 400 13px/1.7 'Helvetica Neue', sans-serif !important;
	margin: 0 20px 3px 0;
	float: left;
	width: 100px;
}

#jp-carousel-comment-form-button-submit {
	margin-top: 20px;
	margin-left: auto;
	display: block;
	border: solid 1px var(--jp-carousel-primary-color);
	background: var(--jp-carousel-bg-color);
	border-radius: 3px;
	padding: 8px 16px;
	font-size: 14px;
	color: var(--jp-carousel-primary-color);
}

#jp-carousel-comment-form-button-submit:active,
#jp-carousel-comment-form-button-submit:focus {
	background: var(--jp-carousel-primary-color);
	color: var(--jp-carousel-bg-color);
}

#jp-carousel-comment-form-container {
	margin-bottom: 15px;
	width: 100%;
	margin-top: 20px;
	color: var(--jp-carousel-primary-subtle-color);
	position: relative;
	overflow: hidden;
}

#jp-carousel-comment-post-results {
	display: none;
	overflow: auto;
	width: 100%;
}

#jp-carousel-comment-post-results span {
	display: block;
	text-align: center;
	margin-top: 20px;
	width: 100%;
	overflow: auto;
	padding: 1em 0;
	box-sizing: border-box;
	border-radius: 2px;
	font: 13px/1.4 'Helvetica Neue', sans-serif !important;
	border: 1px solid var(--jp-carousel-border-color);
	-webkit-box-shadow: inset 0px 0px 5px 0px rgba( 0, 0, 0, 0.2 );
	box-shadow: inset 0px 0px 5px 0px rgba( 0, 0, 0, 0.2 );
}

.jp-carousel-comment-post-error {
	color: #df4926;
}

#jp-carousel-comments-closed {
	display: none;
	color: var(--jp-carousel-primary-subtle-color);
}

#jp-carousel-comments-loading {
	font: 400 15px/1.7 'Helvetica Neue', sans-serif !important;
	display: none;
	color: var(--jp-carousel-primary-subtle-color);
	text-align: left;
	margin-bottom: 20px;
	width: 100%;
	bottom: 10px;
	margin-top: 20px;
}

/** Icons Start **/
.jp-carousel-photo-icons-container {
	flex: 1;
	display: block;
	text-align: right;
	margin: 0 20px 0 30px;
	white-space: nowrap;
}

.jp-carousel-icon-btn {
	padding: 16px;
	text-decoration: none;
	border: none;
	background: none;
	display: inline-block;
	height: 64px;
}

.jp-carousel-icon {
	border: none;
	display: inline-block;
	line-height: 0;
	font-weight: 400;
	font-style: normal;
	border-radius: 4px;
	width: 31px; /* Prevent comments indicator from changing icon width */
	padding: 4px 3px 3px;
}

.jp-carousel-icon:hover {
	background: var(--jp-carousel-primary-subtle-color);
}

.jp-carousel-icon svg {
	display: inline-block;
}

.jp-carousel-overlay rect {
	fill: var(--jp-carousel-primary-color);
}

.jp-carousel-selected .jp-carousel-icon {
	background: var(--jp-carousel-primary-color);
}
.jp-carousel-selected rect {
	fill: var(--jp-carousel-bg-color);
}

.jp-carousel-icon-comments.jp-carousel-show {
	display: inline-block;
}

.jp-carousel-icon .jp-carousel-has-comments-indicator {
	display: none;
	font-size: 12px;
	vertical-align: top;
	margin-left: -16px;
	line-height: 1;
	padding: 2px 4px;
	border-radius: 4px;
	background: var(--jp-carousel-primary-color);
	color: var(--jp-carousel-bg-color);
	font-weight: normal;
	font-family: 'Helvetica Neue', sans-serif !important;
	position: relative;
}

.jp-carousel-selected .jp-carousel-icon .jp-carousel-has-comments-indicator {
	background: var(--jp-carousel-bg-color);
	color: var(--jp-carousel-primary-color);
}

.jp-carousel-has-comments-indicator.jp-carousel-show {
	display: inline-block;
}

/** Icons End **/

/* Small screens */
@media only screen and ( max-width: 760px ) {
	.jp-carousel-overlay .swiper-container .swiper-button-next,
	.jp-carousel-overlay .swiper-container .swiper-button-prev {
		display: none !important;
	}

	.jp-carousel-buttons {
		display: none !important;
	}

	.jp-carousel-image-meta {
		float: none !important;
		width: 100% !important;
		-moz-box-sizing: border-box;
		-webkit-box-sizing: border-box;
		box-sizing: border-box;
		margin-left: 0;
	}

	.jp-carousel-close-hint {
		font-size: 26px !important;
		position: fixed !important;
		top: 10px;
		right: 10px;
	}

	/* The admin bar is fixed at top: 0*/
	.admin-bar .jp-carousel-close-hint {
		top: 40px;
	}

	.jp-carousel-slide img {
		opacity: 1;
	}

	.jp-carousel-wrap {
		background-color: var(--jp-carousel-bg-color);
	}

	.jp-carousel-fadeaway {
		display: none;
	}

	.jp-carousel-info > .jp-carousel-photo-info {
		display: none;
	}

	.jp-carousel-comments-wrapper > .jp-carousel-photo-info {
		display: block;
	}

	.jp-carousel-caption {
		overflow: visible !important;
	}

	.jp-carousel-info-footer .jp-carousel-photo-title-container {
		display: none;
	}

	.jp-carousel-photo-icons-container {
		margin: 0 10px 0 0;
		white-space: nowrap;
	}

	.jp-carousel-icon-btn {
		padding-left: 20px;
	}

	.jp-carousel-pagination {
		padding-left: 5px;
	}

	.jp-carousel-pagination-container {
		margin-left: 25px;
	}

	.jp-carousel-comment .avatar {
		min-width: 48px;
	}

	#jp-carousel-comment-form-commenting-as fieldset,
	#jp-carousel-comment-form-commenting-as input {
		width: 100%;
		float: none;
	}
}
